import React, { useState, useEffect } from 'react';
import { Form, Input, Button, Card, Radio, notification, Select } from 'antd';
import moment from 'moment';
import request from '@/utils/request';
import apis from '@/services/apis';
// import Styles from './style.less';
import { router } from 'umi';

const { TextArea } = Input;
const { Option } = Select;

const tailFormItemLayout = {
  labelCol: {
    xs: { span: 20 },
    sm: { span: 3 },
  },
  wrapperCol: {
    xs: { span: 20 },
    sm: { span: 16 },
  },
};

const openNotificationWithIcon = (type, message) => {
  notification[type]({
    message,
    description: '',
  });
};

function body(props) {
  const { getFieldDecorator } = props.form;

  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [visibleData, setVisibleData] = useState({
    visible: false,
    customerId: '',
    realtyConsultant: '',
    buildingId: '',
  });

  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [dataSource, setDataSource] = useState({ picture: '' });

  const { id,type } = props.location.query;
  const disabled= type==='detail'

  useEffect(() => {
    if (id !== '') {
      getById(id);
    }
  }, [id]);
  // 获取详情信息
  function getById(currentId) {
    request({ ...apis.searchHouse.IdHouse, urlData: { id: currentId } }).then(res => {
      // res.reportDate = moment(res.reportDate)
      if (res) {
        props.form.setFieldsValue({ ...res, reportDate: moment(res.reportDate) });
        //包裹的没渲染完就执行set 导致在呈现字段之前无法设置表单字段
      }
    });
  }

  function submitDate(params) {
    // props.form.setFieldsValue(res)
    console.log(params, 'params');
    request({
      ...apis.customer.auto,
      urlData: { id: params.customerId || props.form.getFieldValue('customerId') },
      params: {
        verifyStatus: params.verifyStatus,
        realtyConsultant: props.form.getFieldValue('realtyConsultant'),
      },
    })
      .then(() => {
        // eslint-disable-next-line no-unused-expressions
        openNotificationWithIcon('success', '操作成功');
        router.go(-1);
      })
      .catch(err => {
        // eslint-disable-next-line no-unused-expressions
      });
  }

  // 提交事件
  function handleSubmit(e) {
    e.preventDefault();
    props.form.validateFields((err, values) => {
      if (!err) {
        submitDate({ verifyStatus: '1' });
        // submitDate({ ...values })
      }
    });
  }

  return (
    <Card>
      <Form
        {...tailFormItemLayout}
        onSubmit={e => handleSubmit(e)}
        style={{ width: '800px', margin: 'auto' }}
      >
        {/* <Form.Item label="客户ID" style={{ display: 'none' }}>
          {getFieldDecorator('customerId')(<Input placeholder="客户ID" />)}
        </Form.Item> */}
        {/* ············分割线............. */}
        <Form.Item label="意向区域">
          {getFieldDecorator('intention')(<Input placeholder="意向区域：" disabled={disabled}/>)}
        </Form.Item>
        <Form.Item label="客户姓名">
          {getFieldDecorator('name')(<Input placeholder="客户姓名" disabled={disabled}/>)}
        </Form.Item>
        <Form.Item label="客户电话">
          {getFieldDecorator('phone')(<Input placeholder="客户电话" disabled={disabled}/>)}
        </Form.Item>
        <Form.Item label="客户性别">
          {getFieldDecorator('sex')(
            <Radio.Group disabled={disabled}>
              <Radio value={1}>男</Radio>
              <Radio value={2}>女</Radio>
            </Radio.Group>,
          )}
        </Form.Item>
        <Form.Item label="客户预算">
          {getFieldDecorator('name')(<Input placeholder="客户预算" disabled={disabled} suffix="W"/>)}
        </Form.Item>

        <Form.Item label="房屋现状">
          {getFieldDecorator('housetype')(
            <Select placeholder="房屋现状" disabled={disabled}>
              <Option value="新房">毛坯</Option>
              <Option value="旧房装修5年以内">旧房装修5年以内</Option>
              <Option value="旧房装修5-10年">旧房装修5-10年</Option>
              <Option value="旧房装修10年以上">旧房装修10年以上</Option>
            </Select>,
          )}
        </Form.Item>
        <Form.Item label="房屋面积">
          {getFieldDecorator('housetype')(
            <Select placeholder="房屋面积" disabled={disabled}>
              <Option value="1">50m²</Option>
              <Option value="1">50~70m²</Option>
              <Option value="60~90m²">70~90m²</Option>
              <Option value="6~90m²">90~110m²</Option>
              <Option value="110~130m">110~130m²</Option>
              <Option value="130~150m²">130~150m²</Option>  
              <Option value="150~200m²">150~200m²</Option>  
              <Option value="200m²以上">200m²以上</Option>     
            </Select>,
          )}
        </Form.Item>

        <Form.Item label="家装模式">
          {getFieldDecorator('housetype')(
            <Select placeholder="家装模式" disabled={disabled}>
              <Option value="新房">只做设计</Option>
              <Option value="二手房">材料全包</Option>
              <Option value="不限">包工不包料</Option>
              <Option value="二手房">施工包辅材不包主材</Option>
              <Option value="不限">全包</Option>
            </Select>,
          )}
        </Form.Item>

        <Form.Item label="家装侧重点">
          {getFieldDecorator('more')(
            <Checkbox.Group disabled={disabled}>
              <Checkbox value="1">独卫</Checkbox>
              <Checkbox value="2">近地铁</Checkbox>
              <Checkbox value="3">拎包入住</Checkbox>
              <Checkbox value="4">精装修</Checkbox>
              <Checkbox value="5">独立阳台</Checkbox>
              <Checkbox value="6">集中供暖</Checkbox>
              <Checkbox value="7">押一付一</Checkbox>
              <Checkbox value="8">双卫</Checkbox>
              <Checkbox value="9">新上</Checkbox>
              <Checkbox value="10">认证公寓</Checkbox>
            </Checkbox.Group>,
          )}
        </Form.Item>
  

        <Form.Item label="客户备注" >
          {getFieldDecorator('say')(<TextArea placeholder="客户描述" disabled={disabled} rows={7} />)}
        </Form.Item>
        <Form.Item label="回访备注">
          {getFieldDecorator('describe', {
            rules: [{ required: true, message: '请输入回访备注！' }], //v3x必填
          })(<TextArea placeholder="回访备注" disabled={disabled} rows={7} />)}
        </Form.Item>
        <Form.Item style={{ display: 'flex', justifyContent: 'center' }}>
          <Button type="primary" htmlType="submit">
            有效
          </Button>
          &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
          <Button onClick={() => submitDate({ verifyStatus: '2' })}>无效</Button>
        </Form.Item>
      </Form>
    </Card>
  );
}
const HouseCopm = Form.create({ name: 'body' })(body);

export default HouseCopm;
