import React, { useState, useEffect } from 'react';
import { Form, Input, Button, Card, Radio, notification, Select } from 'antd';
import moment from 'moment';
import request from '@/utils/request';
import apis from '@/services/apis';
// import Styles from './style.less';
import { router } from 'umi';

const { TextArea } = Input;
const { Option } = Select;

const tailFormItemLayout = {
  labelCol: {
    xs: { span: 20 },
    sm: { span: 3 },
  },
  wrapperCol: {
    xs: { span: 20 },
    sm: { span: 16 },
  },
};

const openNotificationWithIcon = (type, message) => {
  notification[type]({
    message,
    description: '',
  });
};

function body(props) {
  const { getFieldDecorator } = props.form;

  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [visibleData, setVisibleData] = useState({
    visible: false,
    customerId: '',
    realtyConsultant: '',
    buildingId: '',
  });

  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [dataSource, setDataSource] = useState({ picture: '' });

  const { id,type } = props.location.query;
  const disabled= type==='detail'

  useEffect(() => {
    if (id !== '') {
      getById(id);
    }
  }, [id]);
  // 获取详情信息
  function getById(currentId) {
    request({ ...apis.searchHouse.IdHouse, urlData: { id: currentId } }).then(res => {
      // res.reportDate = moment(res.reportDate)
      if (res) {
        props.form.setFieldsValue({ ...res, reportDate: moment(res.reportDate) });
        //包裹的没渲染完就执行set 导致在呈现字段之前无法设置表单字段
      }
    });
  }

  function submitDate(params) {
    // props.form.setFieldsValue(res)
    console.log(params, 'params');
    request({
      ...apis.customer.auto,
      urlData: { id: params.customerId || props.form.getFieldValue('customerId') },
      params: {
        verifyStatus: params.verifyStatus,
        realtyConsultant: props.form.getFieldValue('realtyConsultant'),
      },
    })
      .then(() => {
        // eslint-disable-next-line no-unused-expressions
        openNotificationWithIcon('success', '操作成功');
        router.go(-1);
      })
      .catch(err => {
        // eslint-disable-next-line no-unused-expressions
      });
  }

  // 提交事件
  function handleSubmit(e) {
    e.preventDefault();
    props.form.validateFields((err, values) => {
      if (!err) {
        submitDate({ verifyStatus: '1' });
        // submitDate({ ...values })
      }
    });
  }

  return (
    <Card>
      <Form
        {...tailFormItemLayout}
        onSubmit={e => handleSubmit(e)}
        style={{ width: '800px', margin: 'auto' }}
      >
        {/* <Form.Item label="客户ID" style={{ display: 'none' }}>
          {getFieldDecorator('customerId')(<Input placeholder="客户ID" />)}
        </Form.Item> */}
        {/* ············分割线............. */}
        <Form.Item label="意向区域">
          {getFieldDecorator('intention')(<Input placeholder="意向区域：" disabled={disabled}/>)}
        </Form.Item>
        <Form.Item label="客户姓名">
          {getFieldDecorator('name')(<Input placeholder="客户姓名" disabled={disabled}/>)}
        </Form.Item>
        <Form.Item label="客户电话">
          {getFieldDecorator('phone')(<Input placeholder="客户电话" disabled={disabled}/>)}
        </Form.Item>
        <Form.Item label="客户性别">
          {getFieldDecorator('sex')(
            <Radio.Group disabled={disabled}>
              <Radio value={1}>男</Radio>
              <Radio value={2}>女</Radio>
            </Radio.Group>,
          )}
        </Form.Item>
        <Form.Item label="客户预算">
          {getFieldDecorator('name')(<Input placeholder="客户预算" disabled={disabled} suffix="W"/>)}
        </Form.Item>
        <Form.Item label="房屋类型">
          {getFieldDecorator('housetype')(
            <Select placeholder="房屋类型" disabled={disabled}>
              <Option value="新房">新房</Option>
              <Option value="二手房">二手房</Option>
              <Option value="不限">不限</Option>
            </Select>,
          )}
        </Form.Item>
        <Form.Item label="意向居室">
          {getFieldDecorator('housetype')(
            <Select placeholder="意向居室" disabled={disabled}>
              <Option value="一居">一居</Option>
              <Option value="二居">二居</Option>
              <Option value="三居">三居</Option>
              <Option value="四居">四居</Option>
              <Option value="五居">五居</Option>
              <Option value="五居以上">五居以上</Option>
            </Select>,
          )}
        </Form.Item>

        <Form.Item label="购房目的">
          {getFieldDecorator('housetype')(
            <Select placeholder="购房目的" disabled={disabled}>
              <Option value="刚需">刚需</Option>
              <Option value="结婚">结婚</Option>
              <Option value="养老">养老</Option>
              <Option value="改善">改善</Option>
              <Option value="教育">教育</Option>
              <Option value="投资">投资</Option>
            </Select>,
          )}
        </Form.Item>
        <Form.Item label="侧重优势">
          {getFieldDecorator('housetype')(
            <Select placeholder="侧重优势" disabled={disabled}>
              <Option value="发展规划">发展规划</Option>
              <Option value="学区">学区</Option>
              <Option value="交通">交通</Option>
              <Option value="配套">配套</Option>
              <Option value="环境">环境</Option>
            
            </Select>,
          )}
        </Form.Item>

        <Form.Item label="社区要求">
          {getFieldDecorator('housetype')(
            <Select placeholder="社区要求" disabled={disabled}>
              <Option value="发展规划">楼栋管家</Option>
              <Option value="学区">金钥匙服务</Option>
              <Option value="交通">社区娱乐</Option>
              <Option value="配套">会所功能</Option>     
            </Select>,
          )}
        </Form.Item>

        <Form.Item label="面积要求">
          {getFieldDecorator('housetype')(
            <Select placeholder="面积要求" disabled={disabled}>
              <Option value="60m²">60m²</Option>
              <Option value="60~90m²">60~90m²</Option>
              <Option value="110~130m">110~130m²</Option>
              <Option value="130~150m²">130~150m²</Option>  
              <Option value="150~200m²">150~200m²</Option>  
              <Option value="200m²以上">200m²以上</Option>     
            </Select>,
          )}
        </Form.Item>

        <Form.Item label="朝向要求">
          {getFieldDecorator('housetype')(
            <Select placeholder="朝向要求" disabled={disabled}>
              <Option value="朝东">朝东</Option>
              <Option value="朝南">朝南</Option>
              <Option value="朝西">朝西</Option>
              <Option value="朝北">朝北</Option>  
              <Option value="南北通透">南北通透</Option>  
                
            </Select>,
          )}
        </Form.Item>

        <Form.Item label="楼层要求" >
          {getFieldDecorator('housetype')(
            <Select placeholder="楼层要求" disabled={disabled}>
             <Option value="低楼层">低楼层</Option>
              <Option value="中楼层">中楼层</Option>
              <Option value="高楼层">高楼层</Option>
              <Option value="底层">底层</Option>  
              <Option value="顶层">顶层</Option>  
                
            </Select>,
          )}
        </Form.Item>

        <Form.Item label="楼龄要求">
          {getFieldDecorator('housetype')(
            <Select placeholder="楼龄要求" disabled={disabled}>
              <Option value="5年以内">5年以内</Option>
              <Option value="10年以内">10年以内</Option>
              <Option value="15年以内">15年以内</Option>
              <Option value="20年以内">20年以内</Option>  
              <Option value="20年以上">20年以上</Option>  
                
            </Select>,
          )}
        </Form.Item>

        <Form.Item label="客户备注" >
          {getFieldDecorator('say')(<TextArea placeholder="客户描述" disabled={disabled} rows={7} />)}
        </Form.Item>
        <Form.Item label="回访备注">
          {getFieldDecorator('describe', {
            rules: [{ required: true, message: '请输入回访备注！' }], //v3x必填
          })(<TextArea placeholder="回访备注" disabled={disabled} rows={7} />)}
        </Form.Item>
        <Form.Item style={{ display: 'flex', justifyContent: 'center' }}>
          <Button type="primary" htmlType="submit">
            有效
          </Button>
          &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
          <Button onClick={() => submitDate({ verifyStatus: '2' })}>无效</Button>
        </Form.Item>
      </Form>
    </Card>
  );
}
const HouseCopm = Form.create({ name: 'body' })(body);

export default HouseCopm;
